Coverage for C:\Users\t590r\Documents\GitHub\suppy\suppy\projections\__init__.py: 100%

1"""Module for simple projection objects."""

2 from ._basic_projections import (

3 BoxProjection,

4 WeightedBoxProjection,

5 HalfspaceProjection,

6 BandProjection,

7 BallProjection,

8 MinDVHProjection,

9 MaxDVHProjection,

10)

11 from ._projection_methods import (

12 SequentialProjection,

13 SimultaneousProjection,

14 BlockIterativeProjection,

15 StringAveragedProjection,

16)

17

18 from ._subgradient_projections import SubgradientProjection, EUDProjection

19

20 __all__ = [

21 "BoxProjection",

22 "WeightedBoxProjection",

23 "HalfspaceProjection",

24 "BandProjection",

25 "BallProjection",

26 "MinDVHProjection",

27 "MaxDVHProjection",

28 "SequentialProjection",

29 "SimultaneousProjection",

30 "BlockIterativeProjection",

31 "StringAveragedProjection",

32 "SubgradientProjection",

33 "EUDProjection",

34]